@@ -259,7 +259,7 @@ const ModalDialog = new Lang.Class({
         if (this.state == State.OPENED || this.state == State.OPENING)
             return true;
 
-        if (!this.pushModal({ timestamp: timestamp }))
+        if (!this.pushModal(timestamp))
             return false;
 
         this._fadeOpen(onPrimary);
@@ -318,8 +318,11 @@ const ModalDialog = new Lang.Class({
     pushModal: function (timestamp) {
         if (this._hasModal)
             return true;
-        if (!Main.pushModal(this._group, { timestamp: timestamp,
-                                           actionMode: this._actionMode }))
+
+        let params = { actionMode: this._actionMode };
+        if (timestamp)
+            params['timestamp'] = timestamp;
+        if (!Main.pushModal(this._group, params))
             return false;
 
         this._hasModal = true;
